BASE_URL = "https://staging.api.pymetrics.com"

ENV_NAME_CLIENT_ID = "MERCURY_CLIENT_ID"
ENV_NAME_CLIENT_SECRET = "MERCURY_CLIENT_SECRET"
ENV_NAME_X_API_KEY = "MERCURY_X_API_KEY"
ASSESSMENT_ID = "[INSERT ASSESSMENT UUID HERE]"
ORDER_UUID = "[INSERT ORDER UUID HERE]"
CANDIDATE_ID = "[INSERT CANDIDATE ID HERE]"
JOB_APPLICATION_ID = "[INSERT JOB APPLICATION ID HERE]"
