from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.assessment_type import AssessmentType

T = TypeVar("T", bound="MercuryAssessment")


@attr.s(auto_attribs=True)
class MercuryAssessment:
    """  """

    id: str
    type: AssessmentType
    description: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        type = self.type.value

        description = self.description

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {"id": id, "type": type, "description": description,}
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        type = AssessmentType(d.pop("type"))

        description = d.pop("description")

        mercury_assessment = cls(id=id, type=type, description=description,)

        mercury_assessment.additional_properties = d
        return mercury_assessment

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
